@@ -4,7 +4,6 @@
 package org.gcube.portlets.user.td.openwidget.client;
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.List;
 
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
@@ -20,6 +19,7 @@ import org.gcube.portlets.user.td.wizardwidget.client.dataresource.ResourceBundl
 import org.gcube.portlets.user.td.wizardwidget.client.util.UtilsGXT3;
 
 import com.allen_sauer.gwt.log.client.Log;
+import com.google.gwt.cell.client.AbstractCell;
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.core.client.Scheduler.ScheduledCommand;
@@ -29,9 +29,12 @@ import com.google.gwt.event.logical.shared.HasSelectionHandlers;
 import com.google.gwt.event.logical.shared.SelectionEvent;
 import com.google.gwt.event.logical.shared.SelectionHandler;
 import com.google.gwt.event.shared.HandlerRegistration;
+import com.google.gwt.safehtml.shared.SafeHtml;
+import com.google.gwt.safehtml.shared.SafeHtmlBuilder;
 import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.sencha.gxt.core.client.IdentityValueProvider;
 import com.sencha.gxt.core.client.Style.SelectionMode;
+import com.sencha.gxt.core.client.XTemplates;
 import com.sencha.gxt.data.client.loader.RpcProxy;
 import com.sencha.gxt.data.shared.ListStore;
 import com.sencha.gxt.data.shared.ModelKeyProvider;
@@ -43,13 +46,14 @@ import com.sencha.gxt.data.shared.loader.ListLoadResultBean;
 import com.sencha.gxt.data.shared.loader.ListLoader;
 import com.sencha.gxt.data.shared.loader.LoadResultListStoreBinding;
 import com.sencha.gxt.widget.core.client.ContentPanel;
-import com.sencha.gxt.widget.core.client.Dialog.PredefinedButton;
 import com.sencha.gxt.widget.core.client.box.ConfirmMessageBox;
 import com.sencha.gxt.widget.core.client.button.TextButton;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer.VerticalLayoutData;
-import com.sencha.gxt.widget.core.client.event.HideEvent;
-import com.sencha.gxt.widget.core.client.event.HideEvent.HideHandler;
+import com.sencha.gxt.widget.core.client.event.DialogHideEvent;
+import com.sencha.gxt.widget.core.client.event.DialogHideEvent.DialogHideHandler;
+import com.sencha.gxt.widget.core.client.event.RowDoubleClickEvent;
+import com.sencha.gxt.widget.core.client.event.RowDoubleClickEvent.RowDoubleClickHandler;
 import com.sencha.gxt.widget.core.client.event.SelectEvent;
 import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
 import com.sencha.gxt.widget.core.client.form.TextField;
@@ -72,25 +76,16 @@ import com.sencha.gxt.widget.core.client.toolbar.ToolBar;
 public class TabResourcesSelectionPanel extends ContentPanel implements
 		HasSelectionHandlers<TabResource> {
 
-	private static final TabResourcesProperties properties = GWT
-			.create(TabResourcesProperties.class);
+	interface NameTooltipTemplates extends XTemplates {
+		@XTemplate("<span qtip=\"{desc}\" qtitle=\"{value}\">{value}</span>")
+		SafeHtml format(String value, String desc);
 
-	protected static final ColumnConfig<TabResource, String> nameColumn = new ColumnConfig<TabResource, String>(
-			properties.name(), 90, "Name");
-	protected static final ColumnConfig<TabResource, String> typeColumn = new ColumnConfig<TabResource, String>(
-			properties.tabResourceType(), 30, "Type");
-	protected static final ColumnConfig<TabResource, String> tableTypeNameColumn = new ColumnConfig<TabResource, String>(
-			properties.tableTypeName(), 30, "Table Type");
-	protected static final ColumnConfig<TabResource, String> agencyColumn = new ColumnConfig<TabResource, String>(
-			properties.agency(), 60, "Agency");
-	protected static final ColumnConfig<TabResource, String> ownerColumn = new ColumnConfig<TabResource, String>(
-			properties.ownerLogin(), 70, "Owner");
-	protected static final ColumnConfig<TabResource, String> dateColumn = new ColumnConfig<TabResource, String>(
-			properties.date(), 50, "Date");
+	}
 
-	protected Grid<TabResource> grid;
-	protected ResourceBundle res;
-	protected Menu contextMenu;
+	
+	private Grid<TabResource> grid;
+	private ResourceBundle res;
+	private Menu contextMenu;
 
 	private TabResource removableTR;
 
@@ -109,11 +104,8 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 			e.printStackTrace();
 		}
 		try {
-			buildPanel(properties.id(),
-					Arrays.<ColumnConfig<TabResource, ?>> asList(nameColumn,typeColumn,
-							tableTypeNameColumn, ownerColumn, agencyColumn, dateColumn),
-					nameColumn);
-
+			buildPanel();
+					
 		} catch (Throwable e) {
 			Log.debug("Error building panel:" + e.getMessage());
 			e.printStackTrace();
@@ -122,13 +114,9 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 	protected void init() {
 		setHeaderVisible(false);
-		// new Resizable(this, Dir.E, Dir.SE, Dir.S);
-
 	}
 
-	protected void buildPanel(ModelKeyProvider<TabResource> keyProvider,
-			List<ColumnConfig<TabResource, ?>> columns,
-			ColumnConfig<TabResource, ?> autoexpandColumn) {
+	protected void buildPanel() {
 
 		ToolBar toolBar = new ToolBar();
 		toolBar.add(new LabelToolItem("Search: "));
@@ -144,11 +132,12 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		IdentityValueProvider<TabResource> identity = new IdentityValueProvider<TabResource>();
 		final CheckBoxSelectionModel<TabResource> sm = new CheckBoxSelectionModel<TabResource>(
 				identity);
-
-		ColumnModel<TabResource> cm = new ColumnModel<TabResource>(columns);
-
+		
+		TabResourcesProperties properties = GWT
+				.create(TabResourcesProperties.class);
+		
 		final ExtendedListStore<TabResource> store = new ExtendedListStore<TabResource>(
-				keyProvider);
+				properties.id());
 
 		searchField.addKeyUpHandler(new KeyUpHandler() {
 
@@ -171,6 +160,83 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 		store.setEnableFilters(true);
 
+		
+		
+
+		ColumnConfig<TabResource, String> nameColumn = new ColumnConfig<TabResource, String>(
+				properties.name(), 90, "Name");
+		
+		
+		/*
+		nameColumn.setCell(
+		new AbstractCell<String>() {
+
+			@Override
+			public void render(Context context, String value, SafeHtmlBuilder sb) {
+				TabResource tabResource=store.get(context.getIndex());
+				
+				final NameTooltipTemplates nameToolTipTemplates = GWT
+						.create(NameTooltipTemplates.class);
+				String valueSafe="";
+				String descriptionSafe="";
+				
+				if(value!=null){		
+						valueSafe=SafeHtmlUtils.htmlEscape(value);
+				}
+				if(tabResource!=null && tabResource.getAgency()!=null){
+					descriptionSafe=SafeHtmlUtils.htmlEscape(tabResource.getAgency());
+				}
+				sb.append(nameToolTipTemplates.format(valueSafe, descriptionSafe));
+
+			}
+		});*/
+		
+		ColumnConfig<TabResource, String> typeColumn = new ColumnConfig<TabResource, String>(
+				properties.tabResourceType(), 30, "Type");
+		ColumnConfig<TabResource, String> tableTypeNameColumn = new ColumnConfig<TabResource, String>(
+				properties.tableTypeName(), 30, "Table Type");
+		ColumnConfig<TabResource, Boolean> lockedColumn = new ColumnConfig<TabResource, Boolean>(
+				properties.locked(), 20, "Lock");
+		ColumnConfig<TabResource, String> agencyColumn = new ColumnConfig<TabResource, String>(
+				properties.agency(), 60, "Agency");
+		ColumnConfig<TabResource, String> ownerColumn = new ColumnConfig<TabResource, String>(
+				properties.ownerLogin(), 70, "Owner");
+		ColumnConfig<TabResource, String> dateColumn = new ColumnConfig<TabResource, String>(
+				properties.date(), 50, "Creation Date");
+
+		lockedColumn.setCell(new AbstractCell<Boolean>() {
+
+			@Override
+			public void render(Context context, Boolean value,
+					SafeHtmlBuilder sb) {
+
+				if (value) {
+					sb.appendHtmlConstant("<img style='margin:auto;padding:auto;display:block;' src='"
+							+ ResourceBundleTDOpen.INSTANCE.lock().getSafeUri()
+									.asString() + "' alt='true'>");
+
+				} else {
+					sb.appendHtmlConstant("<img style='margin:auto;padding:auto;display:block;' src='"
+							+ ResourceBundleTDOpen.INSTANCE.lockOpen().getSafeUri()
+									.asString() + "' alt='true'>");
+				}
+
+			}
+		});
+		
+		List<ColumnConfig<TabResource, ?>> columns=new ArrayList<ColumnConfig<TabResource,?>>();
+		columns.add(nameColumn);
+		columns.add(typeColumn);
+		columns.add(tableTypeNameColumn);
+		columns.add(lockedColumn);
+		columns.add(ownerColumn);
+		columns.add(agencyColumn);
+		columns.add(dateColumn);
+		
+		ColumnModel<TabResource> cm = new ColumnModel<TabResource>(columns);
+
+		
+		
 		RpcProxy<ListLoadConfig, ListLoadResult<TabResource>> proxy = new RpcProxy<ListLoadConfig, ListLoadResult<TabResource>>() {
 
 			public void load(ListLoadConfig loadConfig,
@@ -196,11 +262,14 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 				});
 			}
 		};
+		
+	
+		
 
 		sm.setSelectionMode(SelectionMode.SINGLE);
 		grid.setLoader(loader);
 		grid.setSelectionModel(sm);
-		grid.getView().setAutoExpandColumn(autoexpandColumn);
+		grid.getView().setAutoExpandColumn(nameColumn);
 		grid.getView().setStripeRows(true);
 		grid.getView().setColumnLines(true);
 		grid.getView().setAutoFill(true);
@@ -208,6 +277,16 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		grid.setLoadMask(true);
 		grid.setColumnReordering(true);
 
+		grid.addRowDoubleClickHandler(new RowDoubleClickHandler() {
+
+			@Override
+			public void onRowDoubleClick(RowDoubleClickEvent event) {
+				int rowIndex = event.getRowIndex();
+				requestOpen(rowIndex);
+			}
+
+		});
+
 		SelectHandler sh = new SelectHandler() {
 			public void onSelect(SelectEvent event) {
 				loader.load();
@@ -227,6 +306,19 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		setWidget(con);
 	}
 
+	/**
+	 * 
+	 * @param rowIndex
+	 */
+	protected void requestOpen(int rowIndex) {
+		TabResource tabResource = grid.getStore().get(rowIndex);
+		if (tabResource != null) {
+			parent.getTdOpenSession().setSelectedTabResource(tabResource);
+			parent.retrieveLastTable();
+		}
+
+	}
+
 	protected void createContextMenu() {
 		contextMenu = new Menu();
 		MenuItem deleteTRItem = new MenuItem("Delete");
@@ -287,8 +379,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 									+ caught.getLocalizedMessage());
 							parent.showErrorAndHide(
 									"Error",
-									"Error retrieving tabular resources on server!",
-									caught);
+									caught.getLocalizedMessage(),"", caught);
 						}
 						callback.onFailure(caught);
 					}
@@ -298,9 +389,9 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 								+ " TabularResources");
 						ArrayList<TabResource> avaibles = new ArrayList<TabResource>();
 						for (TabResource tResource : result) {
-							if (!tResource.isLocked()) {
-								avaibles.add(tResource);
-							}
+							//if (!tResource.isLocked()) {
+							avaibles.add(tResource);
+							//}
 						}
 
 						/*
@@ -334,6 +425,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 	}
 
 	public void gridReload() {
+		grid.getSelectionModel().deselectAll();
 		grid.getLoader().load();
 	}
 
@@ -341,17 +433,33 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		removableTR = tabResource;
 		final ConfirmMessageBox mb = new ConfirmMessageBox("Delete",
 				"Would you like to delete this tabular resource?");
-		mb.addHideHandler(new HideHandler() {
-			public void onHide(HideEvent event) {
-				if (mb.getHideButton() == mb.getButtonById(PredefinedButton.YES
-						.name())) {
+		// Next in GXT 3.1.1
+		mb.addDialogHideHandler(new DialogHideHandler() {
+
+			@Override
+			public void onDialogHide(DialogHideEvent event) {
+				switch (event.getHideButton()) {
+				case NO:
+					break;
+				case YES:
 					callDeleteTabularResource();
-				} else if (mb.getHideButton() == mb
-						.getButtonById(PredefinedButton.NO.name())) {
-					// perform NO action
+					break;
+				default:
+					break;
 				}
+
 			}
 		});
+
+		// TODO
+		/*
+		 * GXT 3.0.1 mb.addHideHandler(new HideHandler() { public void
+		 * onHide(HideEvent event) { if (mb.getHideButton() ==
+		 * mb.getButtonById(PredefinedButton.YES .name())) {
+		 * callDeleteTabularResource(); } else if (mb.getHideButton() == mb
+		 * .getButtonById(PredefinedButton.NO.name())) { // perform NO action }
+		 * } });
+		 */
 		mb.setWidth(300);
 		mb.show();
 
@@ -378,8 +486,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 								Log.error("Error on delete TabResource: "
 										+ caught.getLocalizedMessage());
 								UtilsGXT3.alert("Error",
-										"Error on delete TabResource: "
-												+ caught.getLocalizedMessage());
+												caught.getLocalizedMessage());
 							}
 						}
 					}
