@@ -21,4 +21,20 @@ public interface ResourceBundleTDOpen extends ClientBundle {
 	@Source("delete_32.png")
 	ImageResource delete32();
 	
+	@Source("lock-red.png")
+	ImageResource lock();
+	
+	@Source("lock-red_32.png")
+	ImageResource lock32();
+	
+	@Source("lock-open-green.png")
+	ImageResource lockOpen();
+	
+	@Source("lock-open-green_32.png")
+	ImageResource lockOpen32();
+	
+	
+	
+	
+	
 }
\ No newline at end of file
